@@ -17,6 +17,8 @@ mod bson;
 mod chrono_tz;
 #[cfg(feature = "chrono")]
 mod datetime;
+#[cfg(feature = "decimal")]
+mod decimal;
 #[cfg(feature = "chrono")]
 mod naive_time;
 #[cfg(feature = "secrecy")]
